@@ -18,7 +18,11 @@ class Code:
         return self
 
     def __next__(self) -> str:
-        if self._iter_idx is None or self._iter_code_lines is None or self._iter_num_code_lines is None:
+        if (
+            self._iter_idx is None
+            or self._iter_code_lines is None
+            or self._iter_num_code_lines is None
+        ):
             raise Exception("Code iterator not initialized")
 
         self._iter_idx += 1
